@@ -1,9 +1,11 @@
+"""
+Module containing algoralabs' authorization decorators
+"""
 import functools
 import json
 import logging
-from typing import Tuple, Dict, Any, Callable, Optional
-
 import requests
+from typing import Tuple, Dict, Any, Callable, Optional
 from cachetools import cached, TTLCache
 
 from algoralabs.common.config import EnvironmentConfig
@@ -20,6 +22,18 @@ def authenticate(
         password: Optional[str],
         token: Optional[str]
 ) -> dict:
+    """
+    Authenticates a user and creates a users auth headers
+
+    Args:
+        base_url: URL for signing a user in
+        username:
+        password:
+        token:
+
+    Returns:
+        Auth headers for a request
+    """
     auth_headers = {}
     if token:
         auth_headers = _auth_token(token)
@@ -61,8 +75,12 @@ def authenticated_request(
         env_config: Optional[EnvironmentConfig] = None
 ) -> Callable:
     """
-    """
+    Decorator for requests that need to be authenticated
 
+    Args:
+          request: Method that need auth headers injected into it
+          env_config: Optional environment config
+    """
     @functools.wraps(request)
     def decorator(f):
         @functools.wraps(f)
@@ -91,7 +109,7 @@ def authenticated_request(
                 kwargs["headers"] = headers
             else:
                 error = AuthenticationError("Authentication for the package was configured incorrectly and is either "
-                                            "missing a TOKEN or ALGORA_USER and ALGORA_PWD environment variable(s)")
+                                            "missing a AUTH_TOKEN or ALGORA_USER and ALGORA_PWD environment variable(s)")
                 logger.error(error)
 
             return f(*args, **kwargs)
